import React, { useState, useEffect } from 'react';

import { makeStyles } from '@material-ui/core/styles';
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import Divider from '@material-ui/core/Divider';
import ListItemText from '@material-ui/core/ListItemText';
import ListItemAvatar from '@material-ui/core/ListItemAvatar';
import Avatar from '@material-ui/core/Avatar';
import WorkIcon from '@material-ui/icons/Work';
import Typography from '@material-ui/core/Typography';
import TablePagination from '@material-ui/core/TablePagination';

import Chip from '@material-ui/core/Chip';
import { CircularProgress } from '@material-ui/core';

import Container from '@material-ui/core/Container';
import Box from '@material-ui/core/Box';
import Paper from '@material-ui/core/Paper';

import backend from 'lib/backend';


const useStyles = makeStyles(theme => ({
	root: {
		width: '100%',
		backgroundColor: theme.palette.background.paper,
	},
	inline: {
		display: 'inline',
	},
}));


/*className={classes.inline}*/

const Project = ({ project }) => {

	return (
		<ListItem alignItems="flex-start">
			<ListItemAvatar>
				<Avatar>
					<WorkIcon />
				</Avatar>
			</ListItemAvatar>
			<ListItemText
				primary={ project.name }
				/>
			<ListItemText
				secondary={
					<React.Fragment>
						<Typography
							component="div"
							variant="body2"
							color="textPrimary"
							>
							To languages:
						</Typography>
						{ Array.isArray(project.targetLanguages) && project.targetLanguages.map(l => (<Chip key={ l } label={ l }/>)) }
					</React.Fragment>
				}
				/>
			<ListItemText
				secondary={
					<React.Fragment>
						<Typography
							component="span"
							variant="body2"
							color="textPrimary"
							>
							To languages:
						</Typography>
						{ Array.isArray(project.targetLanguages) && project.targetLanguages.map(l => (<Chip key={ l } label={ l }/>)) }
					</React.Fragment>
				}
				/>
		</ListItem>
	);
}


export default (props) => {
	const classes = useStyles();
    const [ projects, setProjects ] = useState([]);
    const [ loading, setLoading ] = useState(true);

    const fetchProjects = async () => {
        setLoading(true);
        try {
            let response = await backend("/api/projects");
            setProjects(response.body.items);
        } catch (e) {
            //TODO
            setProjects(e);
        }
        setLoading(false);
    };

    useEffect(() => {
        fetchProjects();
    }, []);

    if (!Array.isArray(projects) && projects) {
    	//an error occured - TODO display properly
    	return <div>{ projects.message || projects.msg }</div>
    }

    //construct list items
    const list = [];
    for (let i = 0; i < projects.length; i++) {
    	list.push(<Project key={ `project-${i}` } project={ projects[i] } />);
    	if (i < projects.length - 1) {
    		list.push(<Divider key={ `divider-${i}` } />);
    	}
    }

    if (loading) {
    	list.push(
			<div key="progress" style={{display: 'flex', justifyContent: 'center'}}>
				<CircularProgress />
			</div>
		);
    }

	return (
		<Container maxWidth="md">
			<Box m={ 2 }  className={ classes.root }>
				<Paper>
					<List>
						{ list }
					</List>

					{ projects.length ? (
						<TablePagination
							rowsPerPageOptions={[ 5, 10, 25 ]}
							component="div"
							count={ 4 }
							rowsPerPage={ 20 }
							page={ 0 }
							backIconButtonProps={{
								'aria-label': 'previous page',
							}}
							nextIconButtonProps={{
								'aria-label': 'next page',
							}}
							onChangePage={ null }
							onChangeRowsPerPage={ null }
							/>
						) : null }
				</Paper>
			</Box>
		</Container>
	);
}